==> ormlambda-3.34.7.tar.gz: ormlambda-3.34.7/src/ormlambda/sql/ddl.py <==
from __future__ import annotations
from typing import TYPE_CHECKING
from .elements import ClauseElement

if TYPE_CHECKING:
    from ormlambda.dialects.interface.dialect import Dialect
    from ormlambda import Column
    from ormlambda import Table


class BaseDDLElement(ClauseElement):
    """
    Base class for all DDL elements.
    """

    __visit_name__ = "ddl_element"

    def _compiler(self, dialect: Dialect, **kw) -> str:
        """
        Compile the DDL element into a SQL string.
        """
        return dialect.ddl_compiler(dialect, self, **kw)


class CreateTable(BaseDDLElement):
    """
    Class representing a CREATE TABLE statement.
    """

    __visit_name__ = "create_table"

    def __init__(self, element: Table):
        self.element = element
        self.columns = [CreateColumn(c) for c in element.get_columns()]


class CreateColumn[T](BaseDDLElement):
    """
    Class representing a column in a CREATE TABLE statement.
    """

    __visit_name__ = "create_column"

    def __init__(self, element: Column[T]):
        self.element = element


class CreateSchema(BaseDDLElement):
    __visit_name__ = "create_schema"

    def __init__(self, schema: str, if_not_exists: bool = True):
        self.schema: str = schema
        self.if_not_exists: bool = if_not_exists


class DropSchema(BaseDDLElement):
    __visit_name__ = "drop_schema"

    def __init__(self, schema: str, if_exists: bool = True):
        self.schema = schema
        self.if_exists = if_exists


class SchemaExists(BaseDDLElement):
    __visit_name__ = "schema_exists"

    def __init__(self, schema: str):
        self.schema = schema

==> ormlambda-4.0.5.tar.gz: ormlambda-4.0.5/src/ormlambda/sql/ddl.py <==
from __future__ import annotations
from typing import TYPE_CHECKING
from .elements import ClauseElement

if TYPE_CHECKING:
    from ormlambda import URL
    from ormlambda.dialects import Dialect
    from ormlambda import Column
    from ormlambda import Table


class BaseDDLElement(ClauseElement):
    """
    Base class for all DDL elements.
    """

    __visit_name__ = "ddl_element"

    def _compiler(self, dialect: Dialect, **kw) -> str:
        """
        Compile the DDL element into a SQL string.
        """
        return dialect.ddl_compiler(dialect, self, **kw)


class CreateDropTable:
    def __init__(self, element: Table):
        self.element = element
        self.columns = [CreateColumn(c) for c in element.get_columns()]


class CreateTable(CreateDropTable, BaseDDLElement):
    """
    Class representing a CREATE TABLE statement.
    """

    __visit_name__ = "create_table"


class DropTable(CreateDropTable, BaseDDLElement):
    __visit_name__ = "drop_table"


class CreateColumn[T](BaseDDLElement):
    """
    Class representing a column in a CREATE TABLE statement.
    """

    __visit_name__ = "create_column"

    def __init__(self, element: Column[T]):
        self.element = element


class CreateSchema(BaseDDLElement):
    __visit_name__ = "create_schema"

    def __init__(self, schema: str, if_not_exists: bool = True):
        self.schema: str = schema
        self.if_not_exists: bool = if_not_exists


class DropSchema(BaseDDLElement):
    __visit_name__ = "drop_schema"

    def __init__(self, schema: str, if_exists: bool = True):
        self.schema = schema
        self.if_exists = if_exists


class SchemaExists(BaseDDLElement):
    __visit_name__ = "schema_exists"

    def __init__(self, schema: str):
        self.schema = schema


class CreateBackup(BaseDDLElement):
    __visit_name__ = "create_backup"

    def __init__(self, url: URL):
        self.url = url
